@@ -3,6 +3,7 @@ from pywood.events import BaseEvent
 from pywood.updates.commands import is_command, is_start_command
 from pywood.updates.numbers import is_int_number
 from pywood.updates.texts import is_msg_w_text_to_bot
+from pywood.updates.callbacks import is_callback_query
 
 __all__ = [
     'IncomingText',
@@ -10,8 +11,15 @@ __all__ = [
     'IncomingIntNumber',
     'IncomingUpdate',
     'IncomingStartCommand',
+    'IncomingCallback'
 ]
 
+class IncomingCallback(BaseEvent):
+    """Входящий текст."""
+
+    @staticmethod
+    def happened(update) -> bool:
+        return is_callback_query(update)
 
 class IncomingText(BaseEvent):
     """Входящий текст."""
